plotTrees = function()
{
	library("ape")
	trees = as.matrix(read.table("tt_treesUM.tre",header=FALSE))
	n = dim(trees)[1]
	
	mn   = "100% consensus tree"
	cons100 = getConsensus(trees,1)
	plot(cons100,main=mn)

	mn   = "95% consensus tree"
	cons95 = getConsensus(trees,0.95)
	plot(cons95,main=mn)
	
	mn   = "50% consensus tree"
	cons50 = getConsensus(trees,0.50)
	plot(cons50,main=mn)
	
	plottrees(trees)
}

plottrees <- function(trees)
{
	for(i in 1:length(trees))
	{
		tree <- read.tree(text=trees[i])
		mn = paste("Sampled tree nr. ",i)
		plot(tree,show.node.label=TRUE,root.edge=TRUE, label.offset = 0.1, main=mn)
		add.scale.bar(0,1)
	}
}

distance <- function(trees,species1,species2)
{
	distances <- c()
	for(i in 1:length(trees))
	{
		tree <- read.tree(text=trees[i])
		distMatrix <- cophenetic.phylo(tree)
		distances = c(distances,distMatrix[species1,species2])
	}
	return(distances)
}

getSplitDistances <- function(p_vTrees,p_vSpecies)
{
	nT = length(p_vTrees)
	nS = length(p_vSpecies)/2
	distances = array(0,c(nT,nS))
	species   = array(p_vSpecies,c(2,nS))
	for(t in 1:nT)
	{
		tree <- read.tree(text=p_vTrees[t])
		distMatrix <- cophenetic.phylo(tree)
		for(s in 1:nS)
		{
			distances[t,s] = distMatrix[species[1,s],species[2,s]]
		}
	}
	return(distances)
}

getConsensus <- function(p_vTrees,fraction)
{
	nT = length(p_vTrees)
	xxx = c()
	for(t in 1:nT)
	{
		tree <- read.tree(text=p_vTrees[t])
		xxx = c(xxx,list(tree))
	}
	return(consensus(xxx,p=fraction))
}
